//
//  SITResource.h
//  SitumSDK
//
//  Created by A Barros on 2/3/17.
//  Copyright © 2017 Situm. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 Abstract base class with common properties across Resources
 */
@interface SITResource : NSObject

#pragma mark - Initializers

/**
 Create a resource
 
 @param identifier Identifier of the resource
 @param createdAt Creation date
 @param updatedAt Last updated date
 @param customFields Key-Value pairs that can be used to store information
 @return `SITResource`
 */
- (instancetype  _Nonnull)initWithIdentifier:(NSString * _Nonnull)identifier
                                   createdAt:(NSDate * _Nonnull)createdAt
                                   updatedAt:(NSDate * _Nonnull)updatedAt
                                customFields:(NSDictionary * _Nonnull)customFields;

#pragma mark - Properties

/**
 Unique identifier of the resource
 */
@property(nonatomic, strong) NSString * _Nonnull identifier;


/**
 Date containing the time when a resource was first created.
 */
@property(nonatomic, strong) NSDate * _Nonnull createdAt;

/**
 Date containing the time when a resource was last updated.
 */
@property(nonatomic, strong) NSDate * _Nonnull updatedAt;

/**
 A dictionary containing additional information not managed by Situm SDK
 @note You can use this property to insert personalized content for your application. It will be loaded with the contents inserted on the web app.
 */
@property(nonatomic, strong) NSDictionary * _Nonnull customFields;


@end
