//
//  SITOutdoorLocationOptions.h
//  SitumSDK
//
//  Created by Adrián Rodríguez on 24/01/2020.
//  Copyright © 2020 Situm. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 Building detector strategy to find the building to start the indoor positioning. Default value is GPSProximity.
 */
typedef NS_ENUM(NSInteger, kSITBuildingDetector)
{
    /// Detect the nearest building using the GPS location distance to the building
    kSITGpsProximity = 0,
    /// Detect the building using BLE scans
    kSITBLE,
};

/**
 Outdoor location options used only in indoor-outdoor mode
*/
@interface SITOutdoorLocationOptions : NSObject <NSCopying>

/**
 Building detector strategy to find the building to start the indoor positioning
*/
@property (nonatomic) kSITBuildingDetector buildingDetector;

/**
 Minimum accuracy required, in meters, for an outdoor position to be returned through the LocationManager delegate.
 Default value is zero, so all locations will be returned regardless of its accuracy.
 This parameter only accepts positive values. If a negative value is used, it will be ignored.
 */
@property (nonatomic) NSInteger minimumOutdoorLocationAccuracy;

@end

