//
//  LocationParametersUpdate.h
//  SitumSDK
//
//  Created by Situm on 24/02/2020.
//  Copyright © 2020 Situm. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/**
 Builder block that to configure a SITLocationParametersUpdate instance.
 */
@protocol SITLocationParametersUpdateBuilder<NSObject>

@optional
/**
 Bool value that determines if this update should be applied (true) or not (false)
 */
- (void)setUpdateDevicesToFollow:(BOOL)shouldUpdateDevicesToFollow;
/**
 List of identifiers the system will follow.
 */
- (void)setDevicesToFollow:(NSArray<NSString *> *)devicesToFollow;

@end

/**
 Data structure that stores information about changes in parameters of the location system that will be performed on the fly.
 */
@interface SITLocationParametersUpdate : NSObject

/**
 Bool value that determines if modifying the devices to follow aplies (true) or not (false)
 */
@property (nonatomic, readonly) BOOL updateDevicesToFollow;

/**
 List of identifiers the location system will follow.
 To stop following all the devices you should update the system with an empty list.
 */
@property (nonatomic, readonly) NSArray<NSString *> *devicesToFollow;

/**
 Builder method that creates an instance of SITLocationParametersUpdate class.
 */
+ (instancetype)updateWithBlock:(void(^)(id<SITLocationParametersUpdateBuilder>builder))buildBlock;


@end

NS_ASSUME_NONNULL_END
